@@ -19,7 +19,7 @@ from __future__ import generators
 
 import struct, math, random
 import py2play.action as action, py2play.character as py2play_character
-from py2play import recvall
+#from py2play import recvall
 import soya, soya.ray as ray, soya.widget as widget
 
 from soya import Point, Vector
@@ -48,15 +48,15 @@ class Action:
 from socket import MSG_WAITALL
 
 
-def WRITE_ACTION(socket, action):
-  socket.sendall(struct.pack("!cddi", action.action, action.mouse_x, action.mouse_y, action.round))
+#def WRITE_ACTION(socket, action):
+#  socket.sendall(struct.pack("!cddi", action.action, action.mouse_x, action.mouse_y, action.round))
   
-def READ_ACTION(socket):
-  return Action(*struct.unpack("!cddi", recvall(socket, 21)))
+#def READ_ACTION(socket):
+#  return Action(*struct.unpack("!cddi", recvall(socket, 21)))
 
 action.Action       = Action
-action.READ_ACTION  = READ_ACTION
-action.WRITE_ACTION = WRITE_ACTION
+#action.READ_ACTION  = READ_ACTION
+#action.WRITE_ACTION = WRITE_ACTION
 
 RIGHT  = Vector(None, 1.0,  0.0,  0.0)
 DOWN   = Vector(None, 0.0, -1.0,  0.0)
