@@ -548,25 +548,13 @@ class KeyboardMouseControler(StackControler, widget.Widget):
             character.player.default_action = a = ACTION_WAIT
             
         elif event[0] == soyasdlconst.JOYAXISMOTION:
-          if event[1] == 0:
-            if event[2] == 0:
-              self.d_mouse_x = 0.0
-            elif event[2] < 0:
-              self.keyboard_mode = 1
-              self.d_mouse_x = -0.1
-            elif event[2] > 0:
-              self.keyboard_mode = 1
-              self.d_mouse_x =  0.1
-          elif event[1] == 1:
-            if event[2] == 0:
-              self.d_mouse_y = 0.0
-            elif event[2] < 0:
-              self.keyboard_mode = 1
-              self.d_mouse_y = -0.15
-            elif event[2] > 0:
-              self.keyboard_mode = 1
-              self.d_mouse_y = 0.15
-
+          if event[1] == 0: # X Axis
+            self.d_mouse_x = float(event[2]) / 327680
+            self.keyboard_mode = 1
+          elif event[1] == 1:   # Y Axis
+            self.d_mouse_y = float(event[2]) / 327680
+            self.keyboard_mode = 1
+            
         elif event[0] == soyasdlconst.JOYBUTTONDOWN:
           if event[1] == 0:
             character.player.default_action = a = ACTION_TURBO
