@@ -72,6 +72,8 @@ PARRAIN_PORT = 36079
 MUSIC = 1
 SOUND = 1
 ASYNC_LOAD_MUSIC = 0
+SOUND_SYSTEM = "OpenAL"
+SOUND_SYSTEM = "SDL_mixer"
 
 SPEED             = 1.0
 RACE_NB_LAPS      = 1
@@ -130,10 +132,11 @@ PARRAIN_PORT = %(PARRAIN_PORT)s
 MUSIC            = %(MUSIC)s
 SOUND            = %(SOUND)s
 ASYNC_LOAD_MUSIC = %(ASYNC_LOAD_MUSIC)s
+SOUND_SYSTEM     = '%(SOUND_SYSTEM)s'
 
 """ % globals())
 
-VERSION = "1.0.7"
+VERSION = "1.0.10"
 
 GUI = 0
 
@@ -156,18 +159,59 @@ VEHICLES = {
   _("Tanker" ) : 4,
   }
 
-try:
-  import soya.openal4soya as openal4soya
-except ImportError:
-  MUSIC = 0
-  SOUND = 0
-  print "* Slune * Warning! PyOpenAL not installed; music and sound are disabled!"
 
-try:
-  import ogg.vorbis
-  HAS_OGG = 1
-except ImportError:
-  MUSIC   = 0
-  HAS_OGG = 0
-  print "* Slune * Warning! PyOgg / PyVorbis not installed; music is disabled!"
+if SOUND_SYSTEM == "SDL_mixer":
+  try:
+    import soya.sdl_mixer4soya
+    HAS_OGG = 1
+    
+  except ImportError:
+    print "* Slune * PySDL_mixer not installed, trying PyOpenAL..."
+    
+    try:
+      import soya.openal4soya
+      SOUND_SYSTEM = "OpenAL"
+
+    except ImportError:
+      print "* Slune * Warning! Neither PyOpenAL nor PySDL_mixer are installed; music and sound are disabled!"
+      MUSIC = 0
+      SOUND = 0
+
+    try:
+      import ogg.vorbis
+      HAS_OGG = 1
+    except ImportError:
+      print "* Slune * Warning! PyOpenAL is installed, but not PyOgg / PyVorbis; music is disabled!"
+      MUSIC   = 0
+      HAS_OGG = 0
+    
+    
+if SOUND_SYSTEM == "OpenAL":
+  try:
+    import soya.openal4soya
+    
+  except ImportError:
+    print "* Slune * PyOpenAL not installed, trying PySDL_mixer..."
+    
+    try:
+      import soya.sdl_mixer4soya
+      HAS_OGG = 1
+      SOUND_SYSTEM = "SDL_mixer"
+    
+    except ImportError:
+      print "* Slune * Warning! Neither PyOpenAL nor PySDL_mixer are installed; music and sound are disabled!"
+      MUSIC = 0
+      SOUND = 0
+      
+  else:
+    try:
+      import ogg.vorbis
+      HAS_OGG = 1
+    except ImportError:
+      print "* Slune * Warning! PyOpenAL is installed, but not PyOgg / PyVorbis; music is disabled!"
+      MUSIC   = 0
+      HAS_OGG = 0
+      
+
+
 
