@@ -267,6 +267,7 @@ def MainScreen():
     menu_h_option.choices[4].value = menu_h_option.choices[4].range[globdef.SOUND]
     menu_h_option.choices[5].value = menu_h_option.choices[5].range[globdef.MUSIC]
     menu_h_option.choices[6].value = menu_h_option.choices[6].range[globdef.ASYNC_LOAD_MUSIC]
+    menu_h_option.choices[7].value = globdef.SOUND_SYSTEM
     set_current_menu(menu_h_option)
 
   def back_h_option():
@@ -279,6 +280,7 @@ def MainScreen():
     globdef.SOUND            = (menu_h_option.choices[4].value == _('on'))
     globdef.MUSIC            = (menu_h_option.choices[5].value == _('on'))
     globdef.ASYNC_LOAD_MUSIC = (menu_h_option.choices[6].value == _('on'))
+    globdef.SOUND_SYSTEM     = menu_h_option.choices[7].value
     soya.set_quality(globdef.QUALITY)
     soya.set_video(globdef.SCREEN_WIDTH, globdef.SCREEN_HEIGHT, globdef.FULLSCREEN, 1)
     import slune.sound; reload(slune.sound)
@@ -298,14 +300,6 @@ def MainScreen():
     globdef.DIFFICULTY = menu_p_option.choices[3].range.index(menu_p_option.choices[3].value)
     go_back()
 
-  def show_multi():
-    import socket
-    label_local.text = (_('Local: ')) + socket.gethostname()
-    menu_multi.choices[1].value = str(globdef.PORT)
-    menu_multi.choices[2].value = globdef.PARRAIN_HOST
-    menu_multi.choices[3].value = str(globdef.PARRAIN_PORT)
-    set_current_menu(multi)
-
   def show_campain():
     set_current_menu(campain)
     
@@ -328,17 +322,6 @@ def MainScreen():
     effect2.visible = 0
     title.visible = 0
     
-  def play_multi():
-    globdef.PORT         = int(menu_multi.choices[1].value)
-    globdef.PARRAIN_HOST = menu_multi.choices[2].value
-    globdef.PARRAIN_PORT = int(menu_multi.choices[3].value)
-    if (globdef.PARRAIN_HOST == '') and (globdef.PORT == globdef.PARRAIN_PORT):
-      popup_msg_window(_("Network error!"), _("__networkbadconfig__"))
-      return
-    import slune.player
-    slune.player.join_network_game()
-    soya.set_root_widget(root)
-    
   def play_campain():
     import slune.player
     r = slune.player.start_new_game("level-" + select_campain.choices[select_campain.selected])
@@ -368,12 +351,11 @@ def MainScreen():
   game_menu_1 = soya.widget.ChoiceList(root, [
     soya.widget.Choice(_('Play campain'), show_campain),
     soya.widget.Choice(_('Play level'), show_level),
-    soya.widget.Choice(_('Join multiplayer game'), show_multi),
     soya.widget.Choice(_('Player options'), show_p_option),
     soya.widget.Choice(_('Hardware options'), show_h_option),
     soya.widget.Choice(_('References'), show_references),
     soya.widget.Choice(_('Quit'), go_back)
-    ], cancel = 6)
+    ], cancel = 5)
   game_menu_1.resize_style = CHOICELIST_RESIZE_STYLE
   game_menu_1.visible = 0
 
@@ -387,8 +369,9 @@ def MainScreen():
     soya.widget.Choice(_('Sounds'), None, None, checkbox),
     soya.widget.Choice(_('Music'), None, None, checkbox),
     soya.widget.Choice(_('Async load music'), None, None, checkbox),
+    soya.widget.Choice(_('Sound system'), None, None, ["OpenAL", "SDL_mixer"]),
     soya.widget.Choice(_('Back'), back_h_option)
-    ], cancel = 7)
+    ], cancel = 8)
   menu_h_option.resize_style = CHOICELIST_RESIZE_STYLE
   menu_h_option.visible = 0
 
@@ -402,25 +385,6 @@ def MainScreen():
   menu_p_option.resize_style = CHOICELIST_RESIZE_STYLE
   menu_p_option.visible = 0
 
-  multi = widget.Group(root)
-  multi.visible = 0
-  def multi_process_event(event):
-    menu_multi.process_event(event)
-  multi.process_event = multi_process_event
-  del multi_process_event
-
-  menu_multi = soya.widget.ChoiceList(multi, [
-    soya.widget.Choice(_('Back'), go_back),
-    soya.widget.ChoiceInput(_('Use port')),
-    soya.widget.ChoiceInput(_('Remote host or IP')),
-    soya.widget.ChoiceInput(_('Connect to port')),
-    soya.widget.Choice(_('Start'), play_multi),
-    ], cancel = 0)
-  menu_multi.resize_style = ('maximize', ('percent top', 0.4), 'maximize height', ('margin top', 30), ('margin bottom', 20))
-
-  label_local = widget.Label(multi, None, 1)
-  label_local.resize_style = ('maximize', ('percent top', 0.4))
-
   campain = widget.Group(root)
   campain.visible = 0
   def campain_process_event(event):
