@@ -88,9 +88,7 @@ class Idler(soya.World, idler.Idler):
     soya.set_root_widget(widget.Group())
     soya.root_widget.add(self.camera)
     
-    if globdef.SOUND or globdef.MUSIC:
-      import soya.openal4soya as openal4soya
-      openal4soya.init(self.camera)
+    sound.init(self.camera)
       
     self.blackbands_group    = widget.Group() 
     self.no_blackbands_group = widget.Group()
@@ -234,6 +232,8 @@ class Idler(soya.World, idler.Idler):
     videosequence.MissionCompleted(winner, message).start(tux = character)
     
   def begin_round(self):
+    time.sleep(0.00001) # for sound
+    
     # In THIS order !!! Say to Py2Play the round begin before doing anything !
     idler.Idler.begin_round(self)
     
@@ -259,7 +259,9 @@ class Idler(soya.World, idler.Idler):
     for child in self.children: child.advance_time(proportion)
     soya.root_widget.widget_advance_time(proportion)
     
-  def render(self): soya.render()
+  def render(self):
+    for i in soya.BEFORE_RENDER: i()
+    soya.render()
     
   def end_round(self):
     current = time.time()
@@ -436,8 +438,8 @@ class Level(level.Level, soya.World):
       #if child.__class__.__name__ in ["Bowling", "World", "Pushable"]:
       #if child.__class__.__name__ in ["PlayerCharacter"]:
         child.begin_round()
-      
-    
+        
+        
 def CREATE(level_name):
   if isinstance(level_name, unicode): level_name = level_name.encode("latin")
   lev = pickle.load(open(os.path.join(soya.path[0], soya.World.DIRNAME, level_name + ".data"), "rb"))
