@@ -249,10 +249,7 @@ def clean_mem():
   slune_character.explosions *= 0
   
   soya.set_root_widget(None)
+
+  sound.clean_mem()
   
-  if globdef.MUSIC:
-    import soya.openal4soya as openal4soya
-    openal4soya._CAMERA = None
-    openal4soya._SOURCES_POS_SPEED *= 0
-    
   import gc; gc.collect() # Perform GC after, rather than while, playing !!!
